@@ -1,4 +1,4 @@
-#ident "@(#)cnd.c	@(#)cnd.c	4.5 97/07/27 Copyright (c) 1993 Gert Doering/Chris Lewis"
+#ident "@(#)cnd.c	$Id: cnd.c,v 4.7 1998/03/26 09:17:38 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
 
 #include <stdio.h>
 #include <string.h>
@@ -31,6 +31,9 @@ struct cndtable {
 
 struct cndtable cndtable[] =
 {
+    /* for the ELSA MicroLink/TLV.34: "RING;08912345;08765, ATS153=6 */
+    {"RING;",			&CallerId},
+
     {"RING"},			/* speedups */
     {"OK"},			/* speedups */
     {"CONNECT ",		&Connect},
