@@ -1,4 +1,4 @@
-#ident "@(#)conf_sf.c	4.5 97/07/05 Copyright (c) Gert Doering"
+#ident "$Id: conf_sf.c,v 4.8 1997/12/05 23:44:56 gert Exp $ Copyright (c) Gert Doering"
 
 /* conf_sf.c
  *
@@ -36,10 +36,12 @@ struct conf_data_sendfax c = {
 	{ "modem-handshake", {0}, CT_STRING, C_EMPTY },
 #endif
 	{ "modem-type", {(p_int) DEFAULT_MODEMTYPE}, CT_STRING, C_PRESET },
+	{ "modem-quirks", {0}, CT_INT, C_EMPTY },
 	{ "max-tries", {FAX_SEND_MAX_TRIES}, CT_INT, C_PRESET },
 	{ "max-tries-continue", {TRUE}, CT_BOOL, C_PRESET },
 	{ "speed", {FAX_SEND_BAUD}, CT_INT, C_PRESET },
 	{ "switchbd", {FAX_SEND_SWITCHBD}, CT_INT, C_PRESET },
+	{ "open-delay",	{0}, CT_INT, C_EMPTY },
 #ifdef FAX_SEND_IGNORE_CARRIER
 	{ "ignore-carrier", {TRUE }, CT_BOOL, C_PRESET },
 #else
@@ -87,7 +89,7 @@ conf_data c_a[2];
     }
 
     /* get command line arguments */
-    while ((opt = getopt(argc, argv, "d:vx:ph:l:nm:SC:I:rA:V")) != EOF)
+    while ((opt = getopt(argc, argv, "d:vx:ph:l:nm:SC:I:rA:D:V")) != EOF)
     {
 	switch (opt) {
 	  case 'd':	/* set target directory for polling */
@@ -137,6 +139,9 @@ conf_data c_a[2];
 	  case 'A':
 	    conf_set_string( &c.acct_handle, optarg );
 	    break;
+	  case 'D':
+	    conf_set_string( &c.dial_prefix, optarg );
+	    break;
 	  case 'V':
 	    printf("\nmgetty+sendfax by Gert Doering\n%s\n\n",
 		    mgetty_version);
@@ -180,4 +185,10 @@ void sendfax_get_config _P1( (port), char * port )
     lprintf( L_NOISE, "not reading config file, not configured" );
 #endif
     log_set_llevel( c_int(debug) );
+
+    if ( c_isset(modem_quirks) )
+    {
+        lprintf( L_NOISE, "set modem_quirks: 0x%04x", c_int(modem_quirks));
+	modem_quirks = c_int(modem_quirks);
+    }
 }
