@@ -1,9 +1,12 @@
-#ident "@(#)faxlib.c	4.19 97/07/13 Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.34 1998/02/12 08:25:32 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
  * Module containing generic faxmodem functions (as: send a command, wait
  * for modem responses, parse modem responses)
+ *
+ * Only class 2 and class 2.0 stuff is here. Class 1 stuff is so
+ * different that it goes to a separate library.
  */
 
 #include <stdio.h>
@@ -18,7 +21,7 @@
 #include "policy.h"
 #include "fax_lib.h"
 
-Modem_type modem_type = Mt_class2;	/* if uninitialized, assume class2 */
+Modem_type modem_type = Mt_unknown;	/* uninitialized */
 
 char	fax_remote_id[40];		/* remote FAX id +FTSI */
 char	fax_param[1000];		/* transm. parameters +FDCS */
@@ -117,7 +120,7 @@ int  ix;
 	{
 	    lprintf( L_MESG, "transmission par.: '%s'", line );
 	    strcpy( fax_param, line );
-	    if ( sscanf( &fax_param[ix], "%hd,%hd,%hd,%hd,%hd,%hd,%hd,%hd",
+	    if ( sscanf( &fax_param[ix], "%hd,%hx,%hd,%hd,%hd,%hd,%hd,%hd",
 			 &fax_par_d.vr, &fax_par_d.br, &fax_par_d.wd,
 			 &fax_par_d.ln, &fax_par_d.df, &fax_par_d.ec,
 			 &fax_par_d.bf, &fax_par_d.st ) != 8 )
@@ -310,6 +313,11 @@ int fax_set_l_id _P2( (fd, fax_id), int fd, char * fax_id )
 {
     char flid[60];
 
+#ifdef CLASS1
+    if ( modem_type == Mt_class1 )
+		return fax1_set_l_id( fd, fax_id );
+#endif
+
     if ( modem_type == Mt_class2_0 )
         sprintf( flid, "AT+FLI=\"%.40s\"",  fax_id );
     else
@@ -329,15 +337,28 @@ int fax_set_fdcc _P4( (fd, fine, max, min),
 {
     char buf[50];
 
-#ifndef FAX_USRobotics
-    sprintf( buf, "AT%s=%d,%d,0,2,0,0,0,0",
-	     (modem_type == Mt_class2_0) ? "+FCC" : "+FDCC",
-	     fine, (max/2400) -1 );
-#else /* FAX_USRobotics */
-    /* some versions of the USR firmware got this wrong, so don't set speed
-     */
-    sprintf( buf, "AT+FCC=%d", fine );
+#ifdef CLASS1
+    if ( modem_type == Mt_class1 )
+		return fax1_set_fdcc( fd, fine, max, min );
 #endif
+
+#ifdef FAX_USRobotics			/* will go away...! */
+    modem_quirks |= MQ_USR_FMINSP;
+#endif
+
+    if ( modem_quirks & MQ_USR_FMINSP )
+    {
+	/* some early versions of the USR fax firmware got this wrong, (put 
+	 * "max" speed into register for "min" speed!!) so don't set speed
+	 */
+	sprintf( buf, "AT+FCC=%d", fine );
+    }
+    else				/* standard case, working modem */
+    {
+	sprintf( buf, "AT%s=%d,%d,0,2,0,0,0,0",
+		 (modem_type == Mt_class2_0) ? "+FCC" : "+FDCC",
+		 fine, (max/2400) -1 );
+    }
     
     if ( mdm_command( buf, fd ) == ERROR )
     {
@@ -413,6 +434,10 @@ int faxmodem_bit_order = 0;
 int fax_set_bor _P2( (fd, bor), int fd, int bor )
 {
     char buf[20];
+#ifdef CLASS1
+    if ( modem_type == Mt_class1 )
+		return fax1_set_bor( fd, bor );
+#endif
 
     faxmodem_bit_order = bor;
 
@@ -435,18 +460,38 @@ int fax_set_bor _P2( (fd, bor), int fd, int bor )
 Modem_type fax_get_modem_type _P2( (fd, mclass), int fd, char * mclass )
 {
 int rc;
+char *mc;
 
     /* data modem? unknown mclass? handle as "auto" (for sendfax) */
     if ( strcmp( mclass, "cls2" ) != 0 &&
-	 strcmp( mclass, "c2.0" ) != 0 )
+	 strcmp( mclass, "c2.0" ) != 0 &&
+	 strcmp( mclass, "auto1") != 0 &&
+	 strcmp( mclass, "cls1" ) != 0 )
     {
 	mclass = "auto";
     }
 
-    /* auto-identify */
-    if ( strcmp( mclass, "auto" ) == 0 &&
-	 mdm_identify( fd ) == NOERROR &&
-	 modem_type != Mt_unknown )
+    /* auto-identify via ATI code */
+    if ( strcmp( mclass, "auto" ) == 0 )
+    {
+	if ( mdm_identify( fd ) != NOERROR )  		/* error? */
+			    { mclass = "auto1"; }	/* try auto1 */
+    }
+
+    /* "auto1" is a variant of auto-identify, using AT+FCLASS=?
+     */
+    if ( strcmp( mclass, "auto1" ) == 0 )
+    {
+	mc = mdm_get_idstring( "AT+FCLASS=?", 1, fd );
+
+	lprintf( L_MESG, "available modem classes: %s", mc );
+
+	if      ( strstr( mc, "2.1" ) != NULL ) { modem_type = Mt_class2_1; }
+	else if ( strstr( mc, "2.0" ) != NULL ) { modem_type = Mt_class2_0; }
+	else if ( strstr( mc, "2" ) != NULL )   { modem_type = Mt_class2; }
+    }
+
+    if ( modem_type != Mt_unknown )
     {
 	/* set up modem accordingly */
 	switch( modem_type )
@@ -464,6 +509,7 @@ int rc;
 	if ( rc == NOERROR ) return modem_type;
     }
 
+
     /* not auto-identify, or initialization failed -> try "old way" 
      */
 
@@ -477,6 +523,17 @@ int rc;
 	}
     }
 
+#ifdef CLASS1
+    /* if explicitely requested, do class 1 (EXPERIMENTAL) */
+    if ( strcmp( mclass, "cls1" ) == 0 )
+    {
+	if ( mdm_command( "AT+FCLASS=1", fd ) == SUCCESS )
+	{
+	    return Mt_class1;
+	}
+    }
+#endif
+
     /* not a 2.0 modem (or not allowed to check),
        simply *try* class 2, nothing to loose */
 
@@ -506,15 +563,14 @@ int mdm_identify _P1( (fd), int fd )
     /* try ATI first, ATI<n> later to sub-divide results
      */
     l = mdm_get_idstring( "ATI", 1, fd );
+    lprintf( L_NOISE, "mdm_identify: string '%s'", l );
     
-    if ( l == NULL ) 
+    if ( strcmp( l, "<ERROR>" ) == 0 ) 
     {
 	lprintf( L_WARN, "mdm_identify: can't get modem ID" );
 	return ERROR;
     }
 
-    lprintf( L_NOISE, "mdm_identify: string '%s'", l );
-
     /* all-numerical? */
     p = l;
     while( isdigit(*p) || isspace(*p) ) p++;
@@ -554,13 +610,19 @@ int mdm_identify _P1( (fd), int fd )
 	    mis = mdm_get_idstring( "ATI1", 1, fd );
 	    break;
 	  case 1444:
-	  case 1445:
 	    lprintf( L_MESG, "USR Courier/Sportster v32bis detected (assuming non-fax capable)" );
 	    modem_type=Mt_data;
 	    break;
+	  case 1445:
+	    lprintf( L_MESG, "USR Courier/Sportster v32bis detected (buggy fax implementation)" );
+	    modem_type=Mt_class2_0;
+	    modem_quirks |= MQ_USR_FMINSP;
+	    break;
 	  case 2886:
 	  case 3361:
+	  case 3362:
 	  case 3366:
+	  case 3367:
 	    lprintf( L_MESG, "USR Courier/Sportster V.34(+) detected" );
 	    modem_type=Mt_class2_0;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
@@ -611,6 +673,11 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_data;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    break;
+	  case 643:	/* ATI6/ATI3 for model/firmware info */
+	    lprintf( L_MESG, "ELSA MicroLink ISDN/TLV.34 detected" );
+	    modem_type=Mt_class2_0;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	    break;
 	  case 282:	/* ATI6/ATI3 for model/firmware info */
 	    lprintf( L_MESG, "ELSA MicroLink 28.8 TQV detected" );
 	    modem_type=Mt_class2_0;
@@ -620,8 +687,10 @@ int mdm_identify _P1( (fd), int fd )
 	  case 14400: /* further distinction necessary (ATI3,4,6)! */
 	  case 28800:
 	  case 33600:
+	  case 56000:
 	    lprintf( L_MESG, "Generic Rockwell modem (%d)", mid );
 	    modem_type=Mt_class2;
+	    modem_quirks |= MQ_NO_LQC;
 	    mis = mdm_get_idstring( "ATI3", 1, fd );
 	    if ( mid == 28800 && mis[0] == '\0' )	/* no ATI3 code */
 	    {
@@ -638,6 +707,12 @@ int mdm_identify _P1( (fd), int fd )
 	    }
 	    mis = mdm_get_idstring( "ATI4", 1, fd );
 	    break;
+	  case 2884:
+	    lprintf( L_MESG, "sounds like a Microcom DeskPorte Fast+" );
+	    modem_type=Mt_class2_0;
+	    modem_quirks |= MQ_NO_LQC;		/* +FPS: broken */
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	    break;
 	  default:
 	    lprintf( L_MESG, "unknown numerical modem id %d", mid );
 	    break;
@@ -659,15 +734,24 @@ int mdm_identify _P1( (fd), int fd )
 	    modem_type=Mt_data;
 	}
 	/* got this from bruce@hn.pl.net */
-	else if ( strncmp( l, "1.03", 4 ) == 4 )
+	else if ( strncmp( l, "1.03", 4 ) == 0 )
 	{
 	    lprintf( L_MESG, "Ellcon 14.4+Voice detected" );
 	    modem_type=Mt_data;
 	}
+	/* got this from Matt Atkins, matta@cl-sys.com */
+	else if ( strncmp( l, "1.0", 3 ) == 0 )
+	{
+	    lprintf( L_MESG, "Cirrus Logic Communicator 56 detected" );
+	    modem_type=Mt_unknown;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	}
     }
 
     if ( mis != NULL ) 
 	lprintf( L_MESG, "additional info: '%s'", mis );
+    if ( modem_quirks )
+	lprintf( L_MESG, "modem quirks: %04x", modem_quirks );
 
     return NOERROR;
 }
