@@ -1,4 +1,4 @@
-#ident "@(#)logname.c	3.13 96/07/16 Copyright (c) Gert Doering"
+#ident "$Id: logname.c,v 4.3 1998/04/02 16:45:08 gert Exp $ Copyright (c) Gert Doering"
 
 #include <stdio.h>
 #include "syslibs.h"
@@ -172,6 +172,7 @@ char * ln_escape_prompt _P1( (ep), char * ep )
 /* return TRUE if all letters found in the string are uppercase
  */
 
+#ifdef DO_LCUC_MAP
 boolean ln_all_upper _P1( (string), char * string )
 {
     int i;
@@ -188,6 +189,7 @@ boolean ln_all_upper _P1( (string), char * string )
 
     return TRUE;
 }
+#endif
 	
 
 /* set_env_var( var, string )
@@ -210,15 +212,13 @@ void set_env_var _P2( (var,string), char * var, char * string )
 }
 
 static int timeouts = 0;
-#ifdef MAX_LOGIN_TIME
-static RETSIGTYPE getlog_timeout()
+static RETSIGTYPE getlog_timeout(SIG_HDLR_ARGS)
 {
     signal( SIGALRM, getlog_timeout );
 
     lprintf( L_WARN, "getlogname: timeout\n" );
     timeouts++;
 }
-#endif
 
 /* getlogname()
  *
@@ -229,9 +229,9 @@ static RETSIGTYPE getlog_timeout()
  * If ENV_TTYPROMPT is set, do not read anything
  */
 
-int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
+int getlogname _P6( (prompt, tio, buf, maxsize, max_login_time, do_fido),
 		    char * prompt, TIO * tio, char * buf,
-		    int maxsize, boolean do_timeout )
+		    int maxsize, int max_login_time, boolean do_fido )
 {
     int	 i, r;
     char ch;
@@ -242,8 +242,6 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
     static int ppp_level = 0;
 #endif
     
-    static boolean was_all_uc = FALSE;
-
     /* read character by character! */
     tio_save = *tio;
     tio_mode_raw( tio );
@@ -261,17 +259,17 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
     return 0;
 #else			/* !ENV_TTYPROMPT */
 
-#ifdef MAX_LOGIN_TIME
-    if ( do_timeout )
+    if ( max_login_time > 0 )
     {
 	signal( SIGALRM, getlog_timeout );
-	alarm( MAX_LOGIN_TIME );
+	alarm( max_login_time );
     }
-#endif
 
   newlogin:
 #ifdef FIDO
-    printf( "**EMSI_REQA77E\r\021              \r" );
+    /* send EMSI Request for FIDO (if desired) */
+    if ( do_fido )
+        printf( "**EMSI_REQA77E\r\021              \r" );
   newlogin_noemsi:
 #endif
 
@@ -311,7 +309,6 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
 	    
 	    if ( errno != EINTR ) exit(0);		/* HUP/^D/timeout */
 
-#ifdef MAX_LOGIN_TIME
 	    if ( timeouts <= 1 )			/* first timeout */
 	    {
 		printf( "\r\n\07\r\nHey! Please login now. You have one minute left\r\n" );
@@ -320,14 +317,13 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
 	    else					/* second */
 	    {
 		printf( "\r\n\07\r\nYour login time (%d minutes) ran out. Goodbye.\r\n",
-		       MAX_LOGIN_TIME / 60 );
+		       (max_login_time / 60)+1 );
 		
 		sleep(3);		/* give message time to xmit */
 		lprintf( L_AUDIT, "failed dev=%s, pid=%d, login time out",
 			 Device, getpid() );
 		exit(0);		/* bye bye... */
 	    }
-#endif
 	    ch = CKILL;			/* timeout #1 -> clear input */
 	}
 
@@ -390,6 +386,11 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
 	    continue; 
 #endif
 
+	/* ignore [00] and [01] bytes - seem to be spuriously generated
+	 * when dialing into a ZyXEL 2864DI with X.75 (sometimes)
+	 */
+	if ( ch == 0 || ch == 1 ) continue;
+
 	ch = ch & 0x7f;					/* strip to 7 bit */
 
 	if ( ch == CQUIT ) exit(0);
@@ -498,10 +499,14 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
     /* check whether all letters entered were uppercase, if yes, tell
        user to try again with l/c, if it's all uppercase again on the
        second try, enable UC<->LC mapping
+       (this is mainly for full historic compatibility - off by default)
        */
 
+#ifdef DO_LCUC_MAP
     if ( ln_all_upper( buf ) )
     {
+    static boolean was_all_uc = FALSE;
+
 	if ( !was_all_uc )	/* first time */
 	{
 	    printf("\r\n\nIf your terminal supports lower case letter, please\r\n");
@@ -517,6 +522,7 @@ int getlogname _P5( (prompt, tio, buf, maxsize, do_timeout),
 	    lprintf( L_MESG, "login name all uppercase, set IUCLC OLCUC" );
 	}
     }
+#endif
 
     /* set CR/LF mapping according to the character the input was
        ended with
