@@ -1,4 +1,4 @@
-#ident "@(#)mgetty.c	4.8 97/05/24 Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.12 1998/04/02 17:02:41 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -70,6 +70,7 @@ chat_action_t	ring_chat_actions[] = { { "CONNECT",	A_CONN },
 					{ "RING C",	A_RING3 },
 					{ "RING D",	A_RING4 },
 					{ "RING E",	A_RING5 },
+		/* Hayes Acura */	{ "RING U",	A_RING5 },
 		/* Supra */		{ "RING1",	A_RING1 },
 					{ "RING2",	A_RING2 },
 					{ "RING3",	A_RING3 },
@@ -378,6 +379,7 @@ int main _P2((argc, argv), int argc, char ** argv)
 #endif
     lprintf( L_MESG, "mgetty: %s", mgetty_version);
     lprintf( L_NOISE, "%s compiled at %s, %s", __FILE__, __DATE__, __TIME__ );
+    lprintf( L_NOISE, "user id: %d, parent pid: %d", getuid(), getppid());
 	    
     /* read configuration file */
     mgetty_get_config( Device );
@@ -476,6 +478,7 @@ int main _P2((argc, argv), int argc, char ** argv)
 	{
 	    lprintf( L_AUDIT, "failed in mg_init_data, dev=%s, pid=%d",
 	                      Device, getpid() );
+	    tio_flush_queue( STDIN, TIO_Q_BOTH );	/* unblock flow ctrl */
 	    rmlocks();
 	    exit(1);
 	}
@@ -778,7 +781,7 @@ Ring_got_action:
 		break;
 #endif
 	      case A_FAIL:
-		lprintf( L_AUDIT, "failed A_FAIL dev=%s, pid=%d, caller=%s",
+		lprintf( L_AUDIT, "failed A_FAIL dev=%s, pid=%d, caller='%s'",
 			          Device, getpid(), CallerId );
 		exit(20);
 	      default:
@@ -802,7 +805,7 @@ Ring_got_action:
 		
 	    if ( !cndlookup() )
 	    {
-		lprintf( L_AUDIT, "denied caller dev=%s, pid=%d, caller=%s",
+		lprintf( L_AUDIT, "denied caller dev=%s, pid=%d, caller='%s'",
 			 Device, getpid(), CallerId);
 		clean_line( STDIN, 80 ); /* wait for ringing to stop */
 
@@ -852,7 +855,7 @@ Ring_got_action:
 		}
 
 		lprintf( L_AUDIT, 
-		   "failed %s dev=%s, pid=%d, caller=%s, conn='%s', name='%s'",
+		  "failed %s dev=%s, pid=%d, caller='%s', conn='%s', name='%s'",
 		    what_action == A_TIMOUT? "timeout": "A_FAIL", 
 		    Device, getpid(), CallerId, Connect, CallName );
   
