@@ -1,7 +1,7 @@
 #ifndef ___MGETTY_H
 #define ___MGETTY_H
 
-#ident "@(#)mgetty.h	4.4 97/06/28 Copyright (c) Gert Doering"
+#ident "$Id: mgetty.h,v 4.6 1997/12/05 23:49:40 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.h
  *
@@ -131,9 +131,13 @@ typedef	char	boolean;
 #endif
 
 /* assume that all BSD systems have the siginterrupt() function
+ * for GNU libc 2.x, we need it as well (default behaviour is now "restart")
  */
-#if ( defined(BSD) || defined(sunos4) ) && !defined(NO_SIGINTERRUPT)
-#define HAVE_SIGINTERRUPT
+#if defined(BSD) || defined(sunos4) ||\
+    ( defined(__GLIBC__) && __GLIBC__ >= 2 ) 
+# ifndef NO_SIGINTERRUPT
+#  define HAVE_SIGINTERRUPT
+# endif
 #endif
 
 /* assume that some systems do not have long filenames...
@@ -205,6 +209,7 @@ void	faxrec _PROTO(( char * spool_dir, unsigned int switchbd,
 		        int uid, int gid, int mode, char * mail_to ));
 char *	fax_strerror _PROTO(( int fax_hangup_code ));
 void	faxlib_init _PROTO((void));
+extern	int modem_quirks;
 
 /* initialization stuff: mg_m_init.c */
 int	mg_init_data  _PROTO(( int fd, char * chat_seq[], char * force_seq[]));
