@@ -1,4 +1,4 @@
-#ident "@(#)sendfax.c	4.5 97/07/13 Copyright (c) Gert Doering"
+#ident "$Id: sendfax.c,v 4.13 1998/01/01 20:26:27 gert Exp $ Copyright (c) Gert Doering"
 
 /* sendfax.c
  *
@@ -53,7 +53,7 @@ void exit_usage _P2( (program, msg ),
     fprintf( stderr,
 	     "usage: %s [options] <fax-number> <page(s) in g3-format>\n", program);
     fprintf( stderr,
-	     "\tvalid options: -p, -h, -v, -l <device(s)>, -x <debug>, -n, -S, -r\n");
+	     "\tvalid options: -p, -v, -l <device(s)>, -x <debug>, -n, -S, -r, -D <x>\n");
     lprintf( L_AUDIT, "failed: command line error" );
     exit(1);
 }
@@ -173,6 +173,7 @@ int fax_open_device _P2( (fax_tty, use_stdin),
     }
     
     if ( verbose ) printf( "OK.\n" );
+
     return fd;
 }
 
@@ -205,6 +206,7 @@ int fd;
 void fax_close _P1( (fd),
 		    int fd )
 {
+    tio_flush_queue( fd, TIO_Q_BOTH );		/* unlock flow ctl. */
     fax_send( "AT+FCLASS=0", fd );
     delay(500);
     tio_flush_queue( fd, TIO_Q_BOTH );		/* unlock flow ctl. */
@@ -327,7 +329,7 @@ int main _P2( (argc, argv),
 
     if ( fd == -1 )
     {
-	lprintf( L_WARN, "cannot open fax device(s)" );
+	lprintf( L_AUDIT, "failed: can't get modem (locked/permissions)");
 	fprintf( stderr, "%s: cannot access fax device(s) (locked?)\n", argv[0] );
 	exit(2);
     }
@@ -338,7 +340,8 @@ int main _P2( (argc, argv),
     /* sanity checks */
     if ( strcmp( c_string(modem_type), "cls2" ) != 0 &&
 	 strcmp( c_string(modem_type), "c2.0" ) != 0 &&
-	 strcmp( c_string(modem_type), "auto" ) != 0 )
+	 strcmp( c_string(modem_type), "cls1" ) != 0 &&
+	 strncmp(c_string(modem_type), "auto", 4) != 0 )
     {
 	fprintf( stderr, "%s: warning: invalid modem class '%s'\n",
 		 argv[0], c_string(modem_type) );
@@ -365,18 +368,35 @@ int main _P2( (argc, argv),
 			argv[0], c_int(speed), Device );
 	close(fd);
 	rmlocks();
+	lprintf( L_AUDIT, "failed: tio_set*, dev=%s, acct=\"%s\"", 
+		     Device, c_string(acct_handle));
 	exit(2);
     }
 
-
-    if ( fax_command( "ATV1Q0", "OK", fd ) == ERROR )
+    /* some modems send an "OK" after DTR is raised - catch it
+     */
+    if ( c_isset(open_delay) )
     {
-	lprintf( L_ERROR, "modem doesn't talk to me" );
-	fprintf( stderr, "The modem doesn't respond!\n" );
-	tio_flush_queue( fd, TIO_Q_BOTH );	/* unlock flow ctl. */
-	close(fd);
-	rmlocks();
-	exit(3);
+	lprintf( L_NOISE, "pausing %d ms", c_int(open_delay));
+	delay(c_int(open_delay));		/* give modem time to settle */
+    }
+    tio_flush_queue(fd, TIO_Q_BOTH);		/* clear junk */
+
+    /* Is there a modem...? */
+    if ( mdm_command( "ATV1Q0", fd ) == ERROR )
+    {
+	/* no??!? -- try again, maybe modem was just unwilling... */
+	if ( mdm_command( "ATV1Q0", fd ) == ERROR )
+	{
+	    lprintf( L_AUDIT, "failed initializing modem, dev=%s, acct=\"%s\"",
+		     Device, c_string(acct_handle) );
+	    fprintf( stderr, "The modem doesn't respond!\n" );
+	    tio_flush_queue( fd, TIO_Q_BOTH );	/* unlock flow ctl. */
+	    close(fd);
+	    rmlocks();
+	    exit(3);
+	}
+	lprintf( L_WARN, "retry succeded, dev=%s", Device );
     }
 
     /* extra initialization: -m / modem-init */
@@ -403,7 +423,7 @@ int main _P2( (argc, argv),
     if ( (modem_type = 
 	  fax_get_modem_type( fd, c_string(modem_type) ) ) == Mt_unknown )
     {
-	lprintf( L_ERROR, "cannot set modem to fax mode" );
+	lprintf( L_AUDIT, "failed: modem type unknown, dev=%s", Device);
 	fprintf( stderr, "%s: cannot set modem to fax mode\n", argv[0] );
 	fax_close( fd );
 	exit( 3 );
@@ -411,7 +431,7 @@ int main _P2( (argc, argv),
 
     if ( modem_type == Mt_data )
     {
-	lprintf( L_ERROR, "modem can't do class 2 or class 2.0" );
+	lprintf( L_AUDIT, "failed: no class 2/2.0 fax modem, dev=%s", Device);
 	fprintf( stderr, "%s: not a class 2/2.0 fax modem\n", argv[0] );
 	fax_close( fd );
 	exit( 3 );
@@ -430,7 +450,7 @@ int main _P2( (argc, argv),
 
     if ( fax_set_l_id( fd, c_string(station_id) ) == ERROR )
     {
-	lprintf( L_ERROR, "cannot set fax station ID" );
+	lprintf( L_AUDIT, "failed: cannot set fax station ID, dev=%s", Device);
 	fprintf( stderr, "%s: cannot set fax station ID\n", argv[0] );
 	fax_close( fd );
 	exit(3);
@@ -481,7 +501,15 @@ int main _P2( (argc, argv),
     call_start = time( NULL );
 
     sprintf( buf, "%s%s", c_string(dial_prefix), fac_tel_no );
-    if ( fax_command( buf, "OK", fd ) == ERROR )
+
+#ifdef CLASS1
+    if ( modem_type == Mt_class1 )
+        i = fax1_dial_and_phase_AB( buf, fd );
+    else
+#endif
+        i = fax_command( buf, "OK", fd );
+
+    if ( i == ERROR )
     {
 	lprintf( L_AUDIT, "failed dialing, phone=\"%s\", +FHS:%02d, dev=%s, time=%ds, acct=\"%s\"",
 		 fac_tel_no, fax_hangup_code, Device,
