@@ -3,16 +3,16 @@
  *
  * Defines the header for raw modem data.
  *
+ * $Id: header.h,v 1.3 1998/03/25 23:04:55 marc Exp $
+ *
  */
 
-#ifdef MAIN
-char *voice_header_h = "$Id: header.h,v 1.2 1996/07/25 19:21:54 marc Exp $";
-#endif
-
 typedef struct
      {
      char magic[4];
      char voice_modem_type[16];
      short compression;
-     char reserved[10];
+     short speed;
+     char bits;
+     char reserved[7];
      } rmd_header;
