@@ -3,12 +3,10 @@
  *
  * Some useful defines.
  *
+ * $Id: util.h,v 1.3 1998/03/25 23:04:56 marc Exp $
+ *
  */
 
-#ifdef MAIN
-char *util_h = "$Id: util.h,v 1.4 1997/01/22 07:35:11 marc Exp $";
-#endif
-
 /*
  * Generic constants
  */
@@ -44,6 +42,7 @@ char *util_h = "$Id: util.h,v 1.4 1997/01/22 07:35:11 marc Exp $";
 #undef XOFF
 #undef DC4
 #undef CAN
+#undef FS
 
 #define ETX  (0x03)
 #define NL   (0x0a)
@@ -53,6 +52,7 @@ char *util_h = "$Id: util.h,v 1.4 1997/01/22 07:35:11 marc Exp $";
 #define XOFF (0x13)
 #define DC4  (0x14)
 #define CAN  (0x18)
+#define FS   (0x1c)
 
 /*
  * Check, that the system we are running on has proper bit sizes and
