@@ -10,27 +10,17 @@
  *
  * Marc
  *
+ * $Id: Dolphin.c,v 1.3 1998/03/25 23:05:31 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_Dolphin_c = "$Id: Dolphin.c,v 1.12 1997/04/11 15:07:23 marc Exp $";
-
-int Dolphin_answer_phone (void)
-     {
-     reset_watchdog(0);
-
-     if ((voice_command("ATA", "VCON") & VMA_USER) != VMA_USER)
-          return(VMA_ERROR);
-
-     return(VMA_OK);
-     }
-
 static int Dolphin_init (void)
      {
      char buffer[VOICE_BUF_LEN];
 
-     reset_watchdog(0);
+     reset_watchdog();
      voice_modem_state = INITIALIZING;
      lprintf(L_MESG, "initializing Dolphin voice modem");
 
@@ -57,7 +47,7 @@ static int Dolphin_init (void)
 
 static int Dolphin_set_compression (int *compression, int *speed, int *bits)
      {
-     reset_watchdog(0);
+     reset_watchdog();
 
      if (*compression == 0)
           *compression = 2;
@@ -67,14 +57,14 @@ static int Dolphin_set_compression (int *compression, int *speed, int *bits)
 
      if (*speed != 9600)
           {
-          lprintf(L_WARN, "%s: Illeagal sample rate (%d)", voice_modem_name,
+          lprintf(L_WARN, "%s: Illegal sample rate (%d)", voice_modem_name,
            *speed);
           return(FAIL);
           };
 
      if (*compression != 2)
           {
-          lprintf(L_WARN, "%s: Illeagal voice compression method (%d)",
+          lprintf(L_WARN, "%s: Illegal voice compression method (%d)",
            voice_modem_name, *compression);
           return(FAIL);
           };
@@ -84,13 +74,12 @@ static int Dolphin_set_compression (int *compression, int *speed, int *bits)
      if (voice_command("AT+VSM=2", "OK") != VMA_USER_1)
           return(FAIL);
 
-     IS_101_set_buffer_size((*speed) * (*bits) / 10 / 8);
      return(OK);
      }
 
 static int Dolphin_set_device (int device)
      {
-     reset_watchdog(0);
+     reset_watchdog();
 
      switch (device)
           {
@@ -116,17 +105,48 @@ static int Dolphin_set_device (int device)
      return(FAIL);
      }
 
+const char Dolphin_pick_phone_cmnd[] = "ATA";
+const char Dolphin_pick_phone_answr[] = "VCON";
+
 voice_modem_struct Dolphin =
      {
      "Dolphin",
      "Dolphin",
-     &Dolphin_answer_phone,
+     (char *) Dolphin_pick_phone_cmnd,
+     (char *) Dolphin_pick_phone_answr,
+     (char *) IS_101_beep_cmnd,
+     (char *) IS_101_beep_answr,
+              IS_101_beep_timeunit,
+     (char *) IS_101_hardflow_cmnd,
+     (char *) IS_101_hardflow_answr,
+     (char *) IS_101_softflow_cmnd,
+     (char *) IS_101_softflow_answr,
+     (char *) IS_101_start_play_cmnd,
+     (char *) IS_101_start_play_answer,
+     (char *) IS_101_reset_play_cmnd,
+     (char *) IS_101_intr_play_cmnd,
+     (char *) IS_101_intr_play_answr,
+     (char *) IS_101_stop_play_cmnd,
+     (char *) IS_101_stop_play_answr,
+     (char *) IS_101_start_rec_cmnd,
+     (char *) IS_101_start_rec_answr,
+     (char *) IS_101_stop_rec_cmnd,
+     (char *) IS_101_stop_rec_answr,
+     (char *) IS_101_switch_mode_cmnd,
+     (char *) IS_101_switch_mode_answr,
+     (char *) IS_101_ask_mode_cmnd,
+     (char *) IS_101_ask_mode_answr,
+     (char *) IS_101_voice_mode_id,
+     &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
      &IS_101_handle_dle,
      &Dolphin_init,
      &IS_101_message_light_off,
      &IS_101_message_light_on,
+     &IS_101_start_play_file,
+     &IS_101_reset_play_file,
+     &IS_101_stop_play_file,
      &IS_101_play_file,
      &IS_101_record_file,
      &Dolphin_set_compression,
