@@ -3,17 +3,17 @@
  *
  * This file contains the Dr. Neuhaus Cybermod specific hardware stuff.
  *
+ * $Id: Dr_Neuhaus.c,v 1.3 1998/03/25 23:05:31 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_Dr_Neuhaus_c = "$Id: Dr_Neuhaus.c,v 1.12 1997/04/11 15:07:25 marc Exp $";
-
 static int Dr_Neuhaus_init (void)
      {
      char buffer[VOICE_BUF_LEN];
 
-     reset_watchdog(0);
+     reset_watchdog();
      voice_modem_state = INITIALIZING;
      lprintf(L_MESG, "initializing Dr. Neuhaus voice modem");
 
@@ -32,10 +32,10 @@ static int Dr_Neuhaus_init (void)
       */
 
      if (cvd.transmit_gain.d.i == -1)
-          cvd.transmit_gain.d.i = 50;
+          cvd.transmit_gain.d.i = 100;
 
-     sprintf(buffer, "AT+VGT=%d", cvd.transmit_gain.d.i * 11 / 100 +
-      122);
+     sprintf(buffer, "AT+VGT=%d", cvd.transmit_gain.d.i * 10 / 100 +
+      123);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "setting transmit gain didn't work");
@@ -45,21 +45,30 @@ static int Dr_Neuhaus_init (void)
       */
 
      if (cvd.receive_gain.d.i == -1)
-          cvd.receive_gain.d.i = 50;
+          cvd.receive_gain.d.i = 40;
 
-     sprintf(buffer, "AT+VGR=%d", cvd.receive_gain.d.i * 11 / 100 +
-      122);
+     sprintf(buffer, "AT+VGR=%d", cvd.receive_gain.d.i * 10 / 100 +
+      123);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "setting receive gain didn't work");
 
+     if (voice_command("AT+VIT=0", "OK") != VMA_USER_1)
+          lprintf(L_WARN, "can't deactivate inactivity timer");
+
+     if (voice_command("AT+VPR=0", "OK") != VMA_USER_1)
+          lprintf(L_WARN, "can't select autobauding");
+
+     if (voice_command("AT+VLS=0", "OK") != VMA_USER_1)
+          lprintf(L_WARN, "can't deselect all input/output devices");
+
      voice_modem_state = IDLE;
      return(OK);
      }
 
 static int Dr_Neuhaus_set_compression (int *compression, int *speed, int *bits)
      {
-     reset_watchdog(0);
+     reset_watchdog();
 
      if (*compression == 0)
           *compression = 129;
@@ -69,7 +78,7 @@ static int Dr_Neuhaus_set_compression (int *compression, int *speed, int *bits)
 
      if (*speed != 8000)
           {
-          lprintf(L_WARN, "%s: Illeagal sample rate (%d)", voice_modem_name,
+          lprintf(L_WARN, "%s: Illegal sample rate (%d)", voice_modem_name,
            *speed);
           return(FAIL);
           };
@@ -98,18 +107,17 @@ static int Dr_Neuhaus_set_compression (int *compression, int *speed, int *bits)
 
                break;
           default:
-               lprintf(L_WARN, "%s: Illeagal voice compression method (%d)",
+               lprintf(L_WARN, "%s: Illegal voice compression method (%d)",
                 voice_modem_name, *compression);
                return(FAIL);
           };
 
-     IS_101_set_buffer_size((*speed) * (*bits) / 10 / 8);
      return(OK);
      }
 
 static int Dr_Neuhaus_set_device (int device)
      {
-     reset_watchdog(0);
+     reset_watchdog();
 
      switch (device)
           {
@@ -133,6 +141,31 @@ voice_modem_struct Dr_Neuhaus =
      {
      "Dr. Neuhaus Cybermod",
      "Dr. Neuhaus",
+     (char *) IS_101_pick_phone_cmnd,
+     (char *) IS_101_pick_phone_answr,
+     (char *) IS_101_beep_cmnd,
+     (char *) IS_101_beep_answr,
+              IS_101_beep_timeunit,
+     (char *) IS_101_hardflow_cmnd,
+     (char *) IS_101_hardflow_answr,
+     (char *) IS_101_softflow_cmnd,
+     (char *) IS_101_softflow_answr,
+     (char *) IS_101_start_play_cmnd,
+     (char *) IS_101_start_play_answer,
+     (char *) IS_101_reset_play_cmnd,
+     (char *) IS_101_intr_play_cmnd,
+     (char *) IS_101_intr_play_answr,
+     (char *) IS_101_stop_play_cmnd,
+     (char *) IS_101_stop_play_answr,
+     (char *) IS_101_start_rec_cmnd,
+     (char *) IS_101_start_rec_answr,
+     (char *) IS_101_stop_rec_cmnd,
+     (char *) IS_101_stop_rec_answr,
+     (char *) IS_101_switch_mode_cmnd,
+     (char *) IS_101_switch_mode_answr,
+     (char *) IS_101_ask_mode_cmnd,
+     (char *) IS_101_ask_mode_answr,
+     (char *) IS_101_voice_mode_id,
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -140,6 +173,9 @@ voice_modem_struct Dr_Neuhaus =
      &Dr_Neuhaus_init,
      &IS_101_message_light_off,
      &IS_101_message_light_on,
+     &IS_101_start_play_file,
+     &IS_101_reset_play_file,
+     &IS_101_stop_play_file,
      &IS_101_play_file,
      &IS_101_record_file,
      &Dr_Neuhaus_set_compression,
