@@ -3,32 +3,17 @@
  *
  * This file contains the ZyXEL 1496 specific hardware stuff.
  *
+ * $Id: ZyXEL_1496.c,v 1.3 1998/03/25 23:05:39 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_ZyXEL_1496_c = "$Id: ZyXEL_1496.c,v 1.24 1997/04/11 15:07:27 marc Exp $";
-
-static int ZyXEL_1496_answer_phone (void)
-     {
-     reset_watchdog(0);
-
-     if (voice_command("AT+VLS=2", "VCON") != VMA_USER_1)
-          return(VMA_FAIL);
-
-     return(VMA_OK);
-     }
-
-static int ZyXEL_1496_beep (int frequency, int length)
-     {
-     return(IS_101_beep(frequency, length / 10));
-     }
-
 static int ZyXEL_1496_init (void)
      {
      char buffer[VOICE_BUF_LEN];
 
-     reset_watchdog(0);
+     reset_watchdog();
      voice_modem_state = INITIALIZING;
      voice_command("ATI1", "");
      voice_read(buffer);
@@ -118,7 +103,6 @@ static int ZyXEL_1496_init (void)
 
 static int ZyXEL_1496_set_compression (int *compression, int *speed, int *bits)
      {
-     reset_watchdog(0);
 
      if (*compression == 0)
           *compression = 2;
@@ -128,7 +112,7 @@ static int ZyXEL_1496_set_compression (int *compression, int *speed, int *bits)
 
      if (*speed != 9600)
           {
-          lprintf(L_WARN, "%s: Illeagal sample rate (%d)", voice_modem_name,
+          lprintf(L_WARN, "%s: Illegal sample rate (%d)", voice_modem_name,
            *speed);
           return(FAIL);
           };
@@ -171,19 +155,17 @@ static int ZyXEL_1496_set_compression (int *compression, int *speed, int *bits)
 
                break;
           default:
-               lprintf(L_WARN, "%s: Illeagal voice compression method (%d)",
+               lprintf(L_WARN, "%s: Illegal voice compression method (%d)",
                 voice_modem_name, *compression);
                return(FAIL);
           };
 
 
-     IS_101_set_buffer_size((*speed) * (*bits) / 10 / 8);
      return(OK);
      }
 
 static int ZyXEL_1496_set_device (int device)
      {
-     reset_watchdog(0);
 
      switch (device)
           {
@@ -213,17 +195,52 @@ static int ZyXEL_1496_set_device (int device)
      return(FAIL);
      }
 
+static char ZyXEL_1496_pick_phone_answr[] = "VCON";
+#define     ZyXEL_1496_beep_timeunit 100
+static char ZyXEL_1496_intr_play_cmnd[] = {DLE, DC4, 0x00};
+static char ZyXEL_1496_intr_play_answr[] = "VCON";
+static char ZyXEL_1496_stop_play_answr[] = "VCON";
+static char ZyXEL_1496_stop_rec_answr[] = "VCON";
+
 voice_modem_struct ZyXEL_1496 =
      {
      "ZyXEL 1496",
      "ZyXEL 1496",
-     &ZyXEL_1496_answer_phone,
-     &ZyXEL_1496_beep,
+     (char *) IS_101_pick_phone_cmnd,
+     (char *) ZyXEL_1496_pick_phone_answr,
+     (char *) IS_101_beep_cmnd,
+     (char *) IS_101_beep_answr,
+              ZyXEL_1496_beep_timeunit,
+     (char *) IS_101_hardflow_cmnd,
+     (char *) IS_101_hardflow_answr,
+     (char *) IS_101_softflow_cmnd,
+     (char *) IS_101_softflow_answr,
+     (char *) IS_101_start_play_cmnd,
+     (char *) IS_101_start_play_answer,
+     (char *) IS_101_reset_play_cmnd,
+     (char *) ZyXEL_1496_intr_play_cmnd,
+     (char *) ZyXEL_1496_intr_play_answr,
+     (char *) IS_101_stop_play_cmnd,
+     (char *) ZyXEL_1496_stop_play_answr,
+     (char *) IS_101_start_rec_cmnd,
+     (char *) IS_101_start_rec_answr,
+     (char *) IS_101_stop_rec_cmnd,
+     (char *) ZyXEL_1496_stop_rec_answr,
+     (char *) IS_101_switch_mode_cmnd,
+     (char *) IS_101_switch_mode_answr,
+     (char *) IS_101_ask_mode_cmnd,
+     (char *) IS_101_ask_mode_answr,
+     (char *) IS_101_voice_mode_id,
+     &IS_101_answer_phone,
+     &IS_101_beep,
      &IS_101_dial,
      &IS_101_handle_dle,
      &ZyXEL_1496_init,
      &IS_101_message_light_off,
      &IS_101_message_light_on,
+     &IS_101_start_play_file,
+     &IS_101_reset_play_file,
+     &IS_101_stop_play_file,
      &IS_101_play_file,
      &IS_101_record_file,
      &ZyXEL_1496_set_compression,
