@@ -9,17 +9,17 @@
  * This version is a complete rewrite to use the IS 101 mode of the
  * Elite 2864.
  *
+ * $Id: ZyXEL_2864.c,v 1.3 1998/03/25 23:05:40 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_ZyXEL_2864_c = "$Id: ZyXEL_2864.c,v 1.17 1997/04/11 15:07:28 marc Exp $";
-
 static int ZyXEL_2864_answer_phone (void)
      {
      int result;
 
-     reset_watchdog(0);
+     reset_watchdog();
 
      if (((result = voice_command("AT+VLS=2", "OK|CONNECT")) & VMA_USER) !=
       VMA_USER)
@@ -35,7 +35,7 @@ static int ZyXEL_2864_init (void)
      {
      char buffer[VOICE_BUF_LEN];
 
-     reset_watchdog(0);
+     reset_watchdog();
      voice_modem_state = INITIALIZING;
      lprintf(L_MESG, "initializing ZyXEL 2864 voice modem");
 
@@ -118,7 +118,7 @@ static int ZyXEL_2864_set_compression (int *compression, int *speed, int *bits)
      {
      char buffer[VOICE_BUF_LEN];
 
-     reset_watchdog(0);
+     reset_watchdog();
 
      if (*compression == 0)
           *compression = 2;
@@ -129,7 +129,7 @@ static int ZyXEL_2864_set_compression (int *compression, int *speed, int *bits)
      if ((*speed != 7200) && (*speed != 8000) && (*speed != 9600) &&
       (*speed != 11025))
           {
-          lprintf(L_WARN, "%s: Illeagal sample rate (%d)", voice_modem_name,
+          lprintf(L_WARN, "%s: Illegal sample rate (%d)", voice_modem_name,
            *speed);
           return(FAIL);
           };
@@ -193,19 +193,18 @@ static int ZyXEL_2864_set_compression (int *compression, int *speed, int *bits)
 
                break;
           default:
-               lprintf(L_WARN, "%s: Illeagal voice compression method (%d)",
+               lprintf(L_WARN, "%s: Illegal voice compression method (%d)",
                 voice_modem_name, *compression);
                return(FAIL);
           };
 
 
-     IS_101_set_buffer_size((*speed) * (*bits) / 10 / 8);
      return(OK);
      }
 
 static int ZyXEL_2864_set_device (int device)
      {
-     reset_watchdog(0);
+     reset_watchdog();
 
      switch (device)
           {
@@ -235,6 +234,31 @@ voice_modem_struct ZyXEL_2864 =
      {
      "ZyXEL 2864",
      "ZyXEL 2864",
+     (char *) IS_101_pick_phone_cmnd,
+     (char *) IS_101_pick_phone_answr,
+     (char *) IS_101_beep_cmnd,
+     (char *) IS_101_beep_answr,
+              IS_101_beep_timeunit,
+     (char *) IS_101_hardflow_cmnd,
+     (char *) IS_101_hardflow_answr,
+     (char *) IS_101_softflow_cmnd,
+     (char *) IS_101_softflow_answr,
+     (char *) IS_101_start_play_cmnd,
+     (char *) IS_101_start_play_answer,
+     (char *) IS_101_reset_play_cmnd,
+     (char *) IS_101_intr_play_cmnd,
+     (char *) IS_101_intr_play_answr,
+     (char *) IS_101_stop_play_cmnd,
+     (char *) IS_101_stop_play_answr,
+     (char *) IS_101_start_rec_cmnd,
+     (char *) IS_101_start_rec_answr,
+     (char *) IS_101_stop_rec_cmnd,
+     (char *) IS_101_stop_rec_answr,
+     (char *) IS_101_switch_mode_cmnd,
+     (char *) IS_101_switch_mode_answr,
+     (char *) IS_101_ask_mode_cmnd,
+     (char *) IS_101_ask_mode_answr,
+     (char *) IS_101_voice_mode_id,
      &ZyXEL_2864_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -242,6 +266,9 @@ voice_modem_struct ZyXEL_2864 =
      &ZyXEL_2864_init,
      &IS_101_message_light_off,
      &IS_101_message_light_on,
+     &IS_101_start_play_file,
+     &IS_101_reset_play_file,
+     &IS_101_stop_play_file,
      &IS_101_play_file,
      &IS_101_record_file,
      &ZyXEL_2864_set_compression,
