@@ -3,14 +3,13 @@
  *
  * Execute the given command and wait for an answer.
  *
+ * $Id: command.c,v 1.3 1998/03/25 23:05:42 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_command_c = "$Id: command.c,v 1.8 1997/04/11 15:07:28 marc Exp $";
-
-int voice_command _P2((command, expected_answer), char *command,
- char *expected_answer)
+int voice_command(char *command, char *expected_answer)
      {
      char buffer[VOICE_BUF_LEN];
      int result = VMA_FAIL;
@@ -45,7 +44,7 @@ int voice_command _P2((command, expected_answer), char *command,
 
                     if (result == VMA_FAIL)
                          {
-                         lprintf(L_ERROR,
+                         lprintf(L_WARN,
                           "%s: Modem did not echo the command", program_name);
                          voice_flush(1);
                          return(VMA_FAIL);
@@ -53,7 +52,7 @@ int voice_command _P2((command, expected_answer), char *command,
 
                     if (result == VMA_ERROR)
                          {
-                         lprintf(L_ERROR, "%s: Modem returned ERROR",
+                         lprintf(L_WARN, "%s: Modem returned ERROR",
                           program_name);
                          voice_flush(1);
                          return(VMA_FAIL);
@@ -81,7 +80,7 @@ int voice_command _P2((command, expected_answer), char *command,
 
                if (result == VMA_FAIL)
                     {
-                    lprintf(L_ERROR, "%s: Invalid modem answer",
+                    lprintf(L_WARN, "%s: Invalid modem answer",
                      program_name);
                     voice_flush(1);
                     return(VMA_FAIL);
@@ -89,7 +88,7 @@ int voice_command _P2((command, expected_answer), char *command,
 
                if (result == VMA_ERROR)
                     {
-                    lprintf(L_ERROR, "%s: Modem returned ERROR",
+                    lprintf(L_WARN, "%s: Modem returned ERROR",
                      program_name);
                     voice_flush(1);
                     return(VMA_FAIL);
