@@ -4,13 +4,13 @@
  * Try all available voice devices and open the first one that
  * suceeds and initialize it.
  *
+ * $Id: open.c,v 1.3 1998/03/25 23:05:46 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_open_c = "$Id: open.c,v 1.8 1997/01/14 06:50:22 marc Exp $";
-
-int voice_open_device _P0(void)
+int voice_open_device(void)
      {
      char *voice_tty_start;
      char *voice_tty_end;
@@ -20,7 +20,7 @@ int voice_open_device _P0(void)
 
      if (strlen(cvd.voice_devices.d.p) == 0)
           {
-          lprintf(L_FATAL,
+          lprintf(L_WARN,
            "no voice modem devices configured in config file");
           exit(FAIL);
           };
@@ -44,33 +44,14 @@ int voice_open_device _P0(void)
           if (makelock(&voice_tty[5]) == OK)
                {
 
-               if ((voice_fd = open(voice_tty, O_RDWR | O_NDELAY | O_NOCTTY))
-                == FAIL)
+               if ((voice_fd = open(voice_tty, O_RDWR | O_NDELAY | O_NOCTTY)) == FAIL)
                     {
-                    lprintf(L_ERROR, "error opening %s", voice_tty);
+                    lprintf(L_WARN, "error opening %s", voice_tty);
                     rmlocks();
                     voice_fd = NO_VOICE_FD;
                     }
                else
-                    {
-
-                    /*
-                     * unset O_NDELAY (otherwise waiting for characters
-                     * would be "busy waiting", eating up all cpu)
-                     */
-
-                    if (fcntl(voice_fd, F_SETFL, O_RDWR) == FAIL)
-                         {
-                         lprintf(L_ERROR, "error in fcntl");
-                         close(voice_fd);
-                         rmlocks();
-                         voice_fd = NO_VOICE_FD;
-                         }
-                    else
-                         lprintf(L_MESG, "opened voice modem device %s",
-                          voice_tty);
-
-                    };
+                    lprintf(L_MESG, "opened voice modem device %s", voice_tty);
 
                };
 
