@@ -3,16 +3,15 @@
  *
  * This command plays the given file.
  *
+ * $Id: play.c,v 1.3 1998/03/25 23:05:46 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_play_c = "$Id: play.c,v 1.7 1997/01/07 05:51:55 marc Exp $";
-
 int voice_play_file (char *name)
      {
-     int fd;
-     int result;
+     FILE *fd;
      rmd_header header;
      int compression;
      int speed;
@@ -20,26 +19,26 @@ int voice_play_file (char *name)
 
      lprintf(L_MESG, "playing voice file %s", name);
 
-     fd = open(name, O_RDONLY);
+     fd = fopen(name, "r");
 
-     if (fd < 0)
+     if (fd == NULL)
           {
-          lprintf(L_ERROR, "%s: Could not open voice file", program_name);
+          lprintf(L_WARN, "%s: Could not open voice file", program_name);
           return(FAIL);
           };
 
      if (!cvd.raw_data.d.i)
           {
 
-          if (read(fd, &header, sizeof(rmd_header)) != sizeof(rmd_header))
+          if (fread(&header, sizeof(rmd_header), 1, fd) != 1)
                {
-               lprintf(L_ERROR, "%s: Could not read header", program_name);
+               lprintf(L_WARN, "%s: Could not read header", program_name);
                return(FAIL);
                };
 
           if (strncmp(header.magic, "RMD1", 4) != 0)
                {
-               lprintf(L_ERROR, "%s: No raw modem data header found",
+               lprintf(L_WARN, "%s: No raw modem data header found",
                 program_name);
                return(FAIL);
                }
@@ -50,7 +49,7 @@ int voice_play_file (char *name)
           if (strncmp(header.voice_modem_type, voice_modem_rmd_name,
            strlen(voice_modem_rmd_name)) != 0)
                {
-               lprintf(L_ERROR, "%s: Wrong modem type found", program_name);
+               lprintf(L_WARN, "%s: Wrong modem type found", program_name);
                return(FAIL);
                }
           else
@@ -71,12 +70,32 @@ int voice_play_file (char *name)
 
      if (voice_modem->set_compression(&compression, &speed, &bits) != OK)
           {
-          lprintf(L_ERROR, "%s: Illeagal compression method", program_name);
-          result = FAIL;
+          lprintf(L_WARN, "%s: Illegal compression method", program_name);
+          return(FAIL);
           }
-     else
-          result = voice_modem->play_file(fd);
 
-     close(fd);
-     return(result);
+     if (voice_modem->start_play_file != NULL)
+
+          if (voice_modem->start_play_file() != OK)
+               {
+               lprintf(L_WARN, "%s: start_play_file command failed", program_name);
+               return(FAIL);
+               }
+
+     if (voice_modem->play_file(fd, speed * bits) != OK)
+          {
+          lprintf(L_WARN, "%s: play_file command failed", program_name);
+          return(FAIL);
+          }
+
+     if (voice_modem->stop_play_file != NULL)
+
+          if (voice_modem->stop_play_file() != OK)
+               {
+               lprintf(L_WARN, "%s: stop_play_file command failed", program_name);
+               return(FAIL);
+               }
+
+     fclose(fd);
+     return(OK);
      }
