@@ -4,12 +4,12 @@
  * Executes the shell script given as the argument. If the argument is
  * empty, commands are read from standard input.
  *
+ * $Id: shell.c,v 1.3 1998/03/25 23:05:49 marc Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *libvoice_shell_c = "$Id: shell.c,v 1.14 1997/04/11 15:07:29 marc Exp $";
-
 static int events_to_shell = FALSE;
 int voice_shell_state = OFF_LINE;
 static int voice_shell_input_fd = NO_VOICE_FD;
@@ -18,19 +18,17 @@ static int child_pid = 0;
 static int level = 0;
 static int autostop = FALSE;
 
-int voice_execute_shell_script _P2((shell_script, shell_options),
- char *shell_script, char **shell_options)
+int voice_execute_shell_script(char *shell_script, char **shell_options)
      {
      int arg_index = 0;
      int start_index;
      char **shell_arguments;
 
      if (strlen(shell_script) == 0)
-          lprintf(L_MESG, "%s: Executing shell %s", program_name,
-           shell_script, cvd.voice_shell.d.p);
+          lprintf(L_MESG, "%s: Executing shell %s", program_name, shell_script, cvd.voice_shell.d.p);
      else
-          lprintf(L_MESG, "%s: Executing shell script %s with shell %s",
-           program_name, shell_script, cvd.voice_shell.d.p);
+          lprintf(L_MESG, "%s: Executing shell script %s with shell %s", program_name, shell_script,
+           cvd.voice_shell.d.p);
 
      if (getenv("VOICE_PID") == NULL)
           {
@@ -42,13 +40,13 @@ int voice_execute_shell_script _P2((shell_script, shell_options),
 
           if (pipe(pipe_in))
                {
-               lprintf(L_ERROR, "%s: cannot open input pipe!", program_name);
+               lprintf(L_WARN, "%s: cannot open input pipe!", program_name);
                return(FAIL);
                };
 
           if (pipe(pipe_out))
                {
-               lprintf(L_ERROR, "%s: cannot open output pipe!", program_name);
+               lprintf(L_WARN, "%s: cannot open output pipe!", program_name);
                return(FAIL);
                };
 
@@ -57,7 +55,7 @@ int voice_execute_shell_script _P2((shell_script, shell_options),
           switch((child_pid = fork()))
                {
                case -1:
-                    lprintf(L_ERROR, "%s: cannot fork!", program_name);
+                    lprintf(L_WARN, "%s: cannot fork!", program_name);
                     return(FAIL);
                case 0:
                     {
@@ -150,12 +148,50 @@ int voice_execute_shell_script _P2((shell_script, shell_options),
 
      shell_arguments[arg_index + start_index] = NULL;
      execv(cvd.voice_shell.d.p, shell_arguments);
-     lprintf(L_ERROR, "%s: cannot execute %s %s", program_name,
+     lprintf(L_WARN, "%s: cannot execute %s %s", program_name,
       cvd.voice_shell.d.p, shell_script);
      exit(99);
      }
 
-int voice_shell_handle_event _P2((event, data), int event, event_data data)
+/*
+ *  variables to set by voice_fax.c
+ */
+
+int voice_fax_hangup_code;
+char *voice_fax_remote_id;
+int voice_fax_pages;
+char *voice_fax_files;
+
+int voice_shell_notify()
+     {
+     voice_write_shell("HUP_CODE\n%d", voice_fax_hangup_code);
+     voice_write_shell("REMOTE_ID\n%s", voice_fax_remote_id);
+
+     if (voice_fax_files != NULL) {
+         char **ap, *av[100];
+      char *cp = voice_fax_files;
+      int i, n;
+
+         for (ap = av, n = 0; (*ap = voice_strsep(&cp, " \t")) != NULL;)
+              if (**ap != '\0') {
+                   ++ap;
+             ++n;
+           }
+
+         if (n > 0) {
+              voice_write_shell("FAX_FILES\n%d", n);
+
+           for (i = 0; i < n; i++)
+                   voice_write_shell("%s", av[i]);
+
+           }
+
+         }
+
+     return 0;
+     }
+
+int voice_shell_handle_event(int event, event_data data)
      {
 
      if (voice_shell_state == OFF_LINE)
@@ -182,8 +218,7 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
 
                if (strcmp(buffer, "HELLO VOICE PROGRAM") != 0)
                     {
-                    lprintf(L_ERROR,
-                     "%s: cannot initialize communication!", program_name);
+                    lprintf(L_WARN, "%s: cannot initialize communication!", program_name);
                     voice_shell_state = OFF_LINE;
                     return(FAIL);
                     };
@@ -209,8 +244,7 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                               voice_stop_current_action();
                               break;
                          case IDLE:
-                              lprintf(L_NOISE, "%s: STOP during IDLE",
-                               program_name);
+                              lprintf(L_NOISE, "%s: STOP during IDLE", program_name);
 
                               if (voice_write_shell("READY") != OK)
                                    return(FAIL);
@@ -226,8 +260,7 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                     }
                else if (level != 1)
                     {
-                    lprintf(L_MESG, "%s: Nested command in shell script",
-                     program_name);
+                    lprintf(L_MESG, "%s: Nested command in shell script", program_name);
 
                     if (voice_write_shell("ERROR") != OK)
                          return(FAIL);
@@ -244,7 +277,9 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                          return(FAIL);
 
                     if (voice_beep(frequency, length) != OK)
-                         return(FAIL);
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
 
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
@@ -283,7 +318,9 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                          return(FAIL);
 
                     if (voice_dial((void *) phone_number) == FAIL)
-                         return(FAIL);
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
 
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
@@ -315,18 +352,18 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                          return(FAIL);
 
                     }
-               else if (strncmp(buffer, "AUTOSTOP", 8) == 0)
+               else if (strcmp(buffer, "AUTOSTOP ON") == 0)
                     {
-                    char buf[VOICE_BUF_LEN] = "";
-                    sscanf(buffer, "%*s %s", buf);
+                    autostop = TRUE;
 
-                    if (strcmp(buf, "ON") == 0)
-                         autostop = 1;
-                    else if (strcmp(buf, "OFF") == 0)
-                         autostop = 0;
-                    else if (voice_write_shell("ERROR") != OK)
+                    if (voice_write_shell("READY") != OK)
                          return(FAIL);
 
+                    }
+               else if (strcmp(buffer, "AUTOSTOP OFF") == 0)
+                    {
+                    autostop = FALSE;
+
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
 
@@ -337,6 +374,65 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                     if (voice_write_shell("GOODBYE SHELL") != OK)
                          return(FAIL);
 
+                    }
+               else if (strncmp(buffer, "GETFAX", 6) == 0)
+                    {
+                    char path[VOICE_BUF_LEN] = "/tmp";
+
+/*
+                    if (voice_device != DIALUP_LINE)
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
+*/
+
+                    sscanf(buffer, "%*s %s", path);
+
+                    if (voice_write_shell("RECEIVING") != OK)
+                         return(FAIL);
+
+                    enter_fax_mode();
+                    voice_write("ATA"); /* faxrec will eat the rest */
+                    voice_faxrec(path, 0);
+                    voice_init();
+                    voice_mode_on();
+                    voice_set_device(DIALUP_LINE);
+                    voice_shell_notify();
+
+                    if (voice_write_shell("READY") != OK)
+                         return(FAIL);
+
+                    }
+               else if (strncmp(buffer, "SENDFAX", 7) == 0)
+                    {
+                    char *cp = &buffer[7];
+                    char **ap, *av[100];
+
+                    for (ap = av; (*ap = voice_strsep(&cp, " \t")) != NULL;)
+
+                         if (**ap != '\0')
+                              ++ap;
+
+                    if (av[0] != NULL)
+                         {
+                         enter_fax_mode();
+                         voice_faxsnd(av, 0, 3);
+                         voice_init();
+                         voice_mode_on();
+                         voice_set_device(DIALUP_LINE);
+                         voice_shell_notify();
+                         }
+                    else
+                         {
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
+
+                         }
+
+                    if (voice_write_shell("READY") != OK)
+                         return(FAIL);
+
                     }
                else if (strncmp(buffer, "PLAY", 4) == 0)
                     {
@@ -351,7 +447,9 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                               return(FAIL);
 
                          if (voice_play_file(name) == FAIL)
-                              return(FAIL);
+
+                              if (voice_write_shell("ERROR") != OK)
+                                   return(FAIL);
 
                          }
                     else
@@ -379,7 +477,9 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                               return(FAIL);
 
                          if (voice_record_file(name) != OK)
-                              return(FAIL);
+
+                              if (voice_write_shell("ERROR") != OK)
+                                   return(FAIL);
 
                          }
                     else
@@ -404,7 +504,9 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
                          return(FAIL);
 
                     if (voice_wait(length) != OK)
-                         return(FAIL);
+
+                         if (voice_write_shell("ERROR") != OK)
+                              return(FAIL);
 
                     if (voice_write_shell("READY") != OK)
                          return(FAIL);
@@ -425,28 +527,23 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
           };
 
 
-     if ((voice_shell_state == ON_LINE) && (event == RECEIVED_DTMF) &&
-      ((event & VOICE_MODEM_EVENT) != 0) && autostop)
+     if ((voice_shell_state == ON_LINE) && (event == RECEIVED_DTMF) && autostop)
 
           switch (voice_modem_state)
                {
                case PLAYING:
                case RECORDING:
-                    lprintf(L_JUNK, "%s: stopping current action",
-                     program_name);
+               case WAITING:
+                    lprintf(L_JUNK, "%s: stopping current action", program_name);
                     voice_stop_current_action();
                     break;
                }
 
-     if ((voice_shell_state == ON_LINE) && (event == RECEIVED_DTMF) &&
-      (!events_to_shell))
+     if ((voice_shell_state == ON_LINE) && (!events_to_shell) && ((event & VOICE_MODEM_EVENT) != 0))
           return(OK);
 
-     if ((voice_shell_state == ON_LINE) && events_to_shell &&
-      ((event & VOICE_MODEM_EVENT) != 0))
+     if ((voice_shell_state == ON_LINE) && events_to_shell && ((event & VOICE_MODEM_EVENT) != 0))
           {
-          lprintf(L_JUNK, "voice_shell_handle_event: event 0x%04x",
-           event);
 
           switch (event)
                {
@@ -586,7 +683,7 @@ int voice_shell_handle_event _P2((event, data), int event, event_data data)
      return(UNKNOWN_EVENT);
      }
 
-int voice_read_shell _P1((buffer), char *buffer)
+int voice_read_shell(char *buffer)
      {
      char char_read;
      int number_chars = 0;
@@ -598,7 +695,7 @@ int voice_read_shell _P1((buffer), char *buffer)
 
           if (read(voice_shell_input_fd, &char_read, 1) != 1)
                {
-               lprintf(L_ERROR, "could not read from shell");
+               lprintf(L_WARN, "could not read from shell");
 
                if (child_pid != 0)
                     kill(child_pid, SIGKILL);
@@ -657,7 +754,7 @@ int voice_write_shell(const char *format, ...)
      if ((write(voice_shell_output_fd, answer, strlen(answer)) !=
       strlen(answer)) || (write(voice_shell_output_fd, "\n", 1) != 1))
           {
-          lprintf(L_ERROR, "%s: could not write to shell", program_name);
+          lprintf(L_WARN, "%s: could not write to shell", program_name);
 
           if (child_pid != 0)
                kill(child_pid, SIGKILL);
