@@ -1,12 +1,12 @@
 /*
  * answer.c
  *
+ * $Id: answer.c,v 1.4 1998/03/26 09:30:54 gert Exp $
+ *
  */
 
 #include "../include/voice.h"
 
-char *vgetty_answer_c = "$Id: answer.c,v 1.17 1997/04/11 15:07:34 marc Exp $";
-
 int answer_mode;
 char dtmf_code[VOICE_BUF_LEN];
 int execute_dtmf_script;
@@ -14,7 +14,7 @@ int first_dtmf;
 int hangup_requested;
 int switch_to_data_fax_mode;
 
-static int enter_data_fax_mode _P1((answer_mode), int answer_mode)
+static int enter_data_fax_mode(int answer_mode)
      {
      int bit_order = 0;
      char *fax_mode = NULL;
@@ -66,6 +66,8 @@ static int enter_data_fax_mode _P1((answer_mode), int answer_mode)
                if (voice_command("AT+FAA=1", "OK") != VMA_USER_1)
                     return(FAIL);
 
+               tio_set(voice_fd, &tio_save);
+               voice_restore_signal_handler();
                fax_set_bor(voice_fd, bit_order);
                break;
           case ANSWER_DATA:
@@ -77,6 +79,8 @@ static int enter_data_fax_mode _P1((answer_mode), int answer_mode)
                if (voice_command("AT+FAA=0", "OK") != VMA_USER_1)
                     return(FAIL);
 
+               tio_set(voice_fd, &tio_save);
+               voice_restore_signal_handler();
                break;
           case ANSWER_FAX:
                lprintf(L_JUNK, "%s: trying fax connection", program_name);
@@ -87,15 +91,16 @@ static int enter_data_fax_mode _P1((answer_mode), int answer_mode)
                if (voice_command("AT+FAA=0", "OK") != VMA_USER_1)
                     return(FAIL);
 
+               tio_set(voice_fd, &tio_save);
+               voice_restore_signal_handler();
                fax_set_bor(voice_fd, bit_order);
                break;
           };
 
-     voice_restore_signal_handler();
      return(OK);
      }
 
-static int get_answer_mode _P1((ring_type), char* ring_type)
+static int get_answer_mode(char* ring_type)
      {
      char answer_mode[VOICE_BUF_LEN] = "";
      int result = 0;
@@ -202,7 +207,7 @@ static int get_answer_mode _P1((ring_type), char* ring_type)
      return(result);
      }
 
-static void get_greeting_message _P1((message), char *message)
+static void get_greeting_message(char *message)
      {
      char message_dir[VOICE_BUF_LEN];
      char list_file_name[VOICE_BUF_LEN];
@@ -229,7 +234,13 @@ static void get_greeting_message _P1((message), char *message)
                strcpy(message_file_name, cvd.backup_message.d.p);
           else
                {
-               choice = time(NULL) % count + 1;
+#ifdef M_UNIX	/* SCO has no srandom */
+               srand(time(NULL) | getpid());
+               choice = rand() % count + 1;
+#else
+               srandom(time(NULL) | getpid());
+               choice = random() % count + 1;
+#endif
                lprintf(L_JUNK,
                 "%s: found %d messages, picked message number %d",
                 program_name, count, choice);
@@ -252,7 +263,7 @@ static void get_greeting_message _P1((message), char *message)
      lprintf(L_JUNK, "%s: message name is %s", program_name, message);
      }
 
-static void remove_message _P1((message), char *message)
+static void remove_message(char *message)
      {
 
      if (!cvd.rec_always_keep.d.i)
@@ -263,12 +274,13 @@ static void remove_message _P1((message), char *message)
 
      }
 
-int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
- int rings_wanted, action_t ring_action)
+int vgetty_answer(int rings, int rings_wanted, action_t ring_action)
      {
      time_t call_start;
      time_t call_end;
      time_t call_length;
+     uid_t uid;
+     gid_t gid;
      char greeting_message[VOICE_BUF_LEN];
      char receive_dir[VOICE_BUF_LEN];
      char message[VOICE_BUF_LEN];
@@ -311,7 +323,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (enter_data_fax_mode(answer_mode) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not switch to data or fax mode",
+               lprintf(L_WARN, "%s: Could not switch to data or fax mode",
                 program_name);
                exit(99);
                }
@@ -332,7 +344,14 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
      if (voice_mode_on() == FAIL)
           {
-          lprintf(L_ERROR, "%s: Could not switch to voice mode",
+          lprintf(L_WARN, "%s: Could not switch to voice mode",
+           program_name);
+          exit(99);
+          }
+
+     if (voice_set_device(DIALUP_LINE) == FAIL)
+          {
+          lprintf(L_WARN, "%s: Could not switch to dialup line",
            program_name);
           exit(99);
           }
@@ -340,12 +359,13 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
      if ((result = voice_answer_phone()) == VMA_CONNECT)
           {
           voice_restore_signal_handler();
+          tio_set(voice_fd, &tio_save);
           return(VMA_CONNECT);
           }
 
      if (result == VMA_ERROR)
           {
-          lprintf(L_ERROR, "%s: Could not answer the phone. Strange...",
+          lprintf(L_WARN, "%s: Could not answer the phone. Strange...",
            program_name);
           exit(99);
           }
@@ -362,7 +382,9 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
           result = voice_execute_shell_script(call_program, arguments);
 
           if (result == FAIL)
-               lprintf(L_ERROR, "%s: shell script %s exited unnormally");
+               {
+               lprintf(L_WARN, "%s: shell script %s exited unnormally");
+               }
           else
 
                switch (result)
@@ -372,7 +394,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
                          if (enter_data_fax_mode(answer_mode & ANSWER_DATA) ==
                           FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not switch to data mode",
                                program_name);
                               exit(99);
@@ -384,7 +406,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
                          if (enter_data_fax_mode(answer_mode & ANSWER_FAX) ==
                           FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not switch to fax mode",
                                program_name);
                               exit(99);
@@ -396,7 +418,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
                          if (enter_data_fax_mode(answer_mode & (ANSWER_DATA |
                           ANSWER_FAX)) == FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not switch to data/fax mode",
                                program_name);
                               exit(99);
@@ -407,7 +429,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
                          if (voice_set_device(NO_DEVICE) == FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not hang up the line",
                                program_name);
                               exit(99);
@@ -415,7 +437,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
                          if (voice_mode_off() == FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not turn off voice mode",
                                program_name);
                               exit(99);
@@ -423,7 +445,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
                          if (voice_close_device() == FAIL)
                               {
-                              lprintf(L_ERROR,
+                              lprintf(L_WARN,
                                "%s: Could not close the voice device",
                                program_name);
                               exit(99);
@@ -435,8 +457,10 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
           };
 
      if (voice_play_file(greeting_message) == FAIL)
-          lprintf(L_ERROR, "%s: Could not play greeting message",
+          {
+          lprintf(L_WARN, "%s: Could not play greeting message",
            program_name);
+          }
 
      if ((execute_dtmf_script) && (strlen(cvd.dtmf_program.d.p) != 0))
           {
@@ -454,21 +478,21 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not hang up the line",
+               lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
 
           if (voice_mode_off() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not turn off voice mode",
+               lprintf(L_WARN, "%s: Could not turn off voice mode",
                 program_name);
                exit(99);
                }
 
           if (voice_close_device() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not close the voice device",
+               lprintf(L_WARN, "%s: Could not close the voice device",
                 program_name);
                exit(99);
                }
@@ -484,21 +508,21 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not hang up the line",
+               lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
 
           if (voice_mode_off() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not turn off voice mode",
+               lprintf(L_WARN, "%s: Could not turn off voice mode",
                 program_name);
                exit(99);
                }
 
           if (voice_close_device() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not close the voice device",
+               lprintf(L_WARN, "%s: Could not close the voice device",
                 program_name);
                exit(99);
                }
@@ -511,7 +535,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (enter_data_fax_mode(answer_mode) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not switch to data/fax mode",
+               lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
                exit(99);
                }
@@ -520,7 +544,9 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
           };
 
      if (voice_beep(cvd.beep_frequency.d.i, cvd.beep_length.d.i) == FAIL)
-          lprintf(L_ERROR, "%s: Beep command failed");
+          {
+          lprintf(L_WARN, "%s: Beep command failed");
+          }
 
      if ((execute_dtmf_script) && (strlen(cvd.dtmf_program.d.p) != 0))
           {
@@ -538,21 +564,21 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not hang up the line",
+               lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
 
           if (voice_mode_off() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not turn off voice mode",
+               lprintf(L_WARN, "%s: Could not turn off voice mode",
                 program_name);
                exit(99);
                }
 
           if (voice_close_device() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not close the voice device",
+               lprintf(L_WARN, "%s: Could not close the voice device",
                 program_name);
                exit(99);
                }
@@ -568,21 +594,21 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not hang up the line",
+               lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
 
           if (voice_mode_off() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not turn off voice mode",
+               lprintf(L_WARN, "%s: Could not turn off voice mode",
                 program_name);
                exit(99);
                }
 
           if (voice_close_device() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not close the voice device",
+               lprintf(L_WARN, "%s: Could not close the voice device",
                 program_name);
                exit(99);
                }
@@ -595,7 +621,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (enter_data_fax_mode(answer_mode) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not switch to data/fax mode",
+               lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
                exit(99);
                }
@@ -607,13 +633,31 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
      if (voice_record_file(message) == FAIL)
           {
-          lprintf(L_ERROR, "%s: Could not record a message",
+          lprintf(L_WARN, "%s: Could not record a message",
            program_name);
           exit(99);
           }
 
      time(&call_end);
      call_length = call_end - call_start;
+     get_ugid((char *) &cvd.phone_owner, (char *) &cvd.phone_group, &uid,
+      &gid);
+
+     /*
+      * change file mode 
+      */
+
+     if ((cvd.phone_mode.d.i != -1) && (chmod(message, cvd.phone_mode.d.i) !=
+      0))
+          lprintf(L_WARN, "%s: cannont change file mode", program_name);
+
+     /* 
+      * change file owner and group 
+      */
+
+     if (chown(message, (uid_t) uid, (gid_t) gid) != 0)
+          lprintf(L_WARN, "%s: cannot change owner and/or group",
+           program_name);
 
      if ((cvd.rec_min_len.d.i != 0) && (call_length <= cvd.rec_min_len.d.i))
           switch_to_data_fax_mode = TRUE;
@@ -635,21 +679,21 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (voice_set_device(NO_DEVICE) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not hang up the line",
+               lprintf(L_WARN, "%s: Could not hang up the line",
                 program_name);
                exit(99);
                }
 
           if (voice_mode_off() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not turn off voice mode",
+               lprintf(L_WARN, "%s: Could not turn off voice mode",
                 program_name);
                exit(99);
                }
 
           if (voice_close_device() == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not close the voice device",
+               lprintf(L_WARN, "%s: Could not close the voice device",
                 program_name);
                exit(99);
                }
@@ -663,7 +707,7 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
 
           if (enter_data_fax_mode(answer_mode) == FAIL)
                {
-               lprintf(L_ERROR, "%s: Could not switch to data/fax mode",
+               lprintf(L_WARN, "%s: Could not switch to data/fax mode",
                 program_name);
                exit(99);
                }
@@ -674,25 +718,25 @@ int vgetty_answer _P3((rings, rings_wanted, ring_action), int rings,
      if (!hangup_requested)
 
           if (voice_beep(cvd.beep_frequency.d.i, cvd.beep_length.d.i) == FAIL)
-               lprintf(L_ERROR, "%s: Beep command failed");
+               lprintf(L_WARN, "%s: Beep command failed");
 
      if (voice_set_device(NO_DEVICE) == FAIL)
           {
-          lprintf(L_ERROR, "%s: Could not hang up the line",
+          lprintf(L_WARN, "%s: Could not hang up the line",
            program_name);
           exit(99);
           }
 
      if (voice_mode_off() == FAIL)
           {
-          lprintf(L_ERROR, "%s: Could not turn off voice mode",
+          lprintf(L_WARN, "%s: Could not turn off voice mode",
            program_name);
           exit(99);
           }
 
      if (voice_close_device() == FAIL)
           {
-          lprintf(L_ERROR, "%s: Could not close the voice device",
+          lprintf(L_WARN, "%s: Could not close the voice device",
            program_name);
           exit(99);
           }
